@@ -1,4 +1,5 @@
 import inspect
+import warnings
 from copy import deepcopy
 from datetime import datetime
 from types import FrameType
@@ -18,7 +19,6 @@ from lightning.app.utilities.packaging.cloud_compute import _maybe_create_cloud_
 
 
 class LightningFlow:
-
     _INTERNAL_STATE_VARS = {
         # Internal protected variables that are still part of the state (even though they are prefixed with "_")
         "_paths",
@@ -249,10 +249,7 @@ class LightningFlow:
 
     @property
     def ready(self) -> bool:
-        """Not currently enabled.
-
-        Override to customize when your App should be ready.
-        """
+        """Override to customize when your App should be ready."""
         flows = self.flows
         return all(flow.ready for flow in flows.values()) if flows else True
 
@@ -370,12 +367,28 @@ class LightningFlow:
         for structure, state in provided_state["structures"].items():
             getattr(self, structure).set_state(state)
 
-    def _exit(self, end_msg: str = "") -> None:
-        """Private method used to exit the application."""
+    def stop(self, end_msg: str = "") -> None:
+        """Method used to exit the application."""
         if end_msg:
             print(end_msg)
         raise ExitAppException
 
+    def _exit(self, end_msg: str = "") -> None:
+        """Used to exit the application.
+
+        Private method.
+
+        .. deprecated:: 1.9.0
+            This function is deprecated and will be removed in 2.0.0. Use :meth:`stop` instead.
+        """
+        warnings.warn(
+            DeprecationWarning(
+                "This function is deprecated and will be removed in 2.0.0. Use `LightningFlow.stop` instead."
+            )
+        )
+
+        return self.stop(end_msg=end_msg)
+
     @staticmethod
     def _is_state_attribute(name: str) -> bool:
         """Every public attribute is part of the state by default and all protected (prefixed by '_') or private
@@ -800,14 +813,14 @@ class _RootFlow(LightningFlow):
     @property
     def ready(self) -> bool:
         ready = getattr(self.work, "ready", None)
-        if ready:
+        if ready is not None:
             return ready
         return self.work.url != ""
 
     def run(self):
         if self.work.has_succeeded:
             self.work.stop()
-            self._exit()
+            self.stop()
         self.work.run()
 
     def configure_layout(self):
