@@ -15,9 +15,9 @@ from typing import Any, Dict, List, Optional, Union
 
 import torch
 
-from lightning.lite.accelerators.tpu import _parse_tpu_cores, _XLA_AVAILABLE
-from lightning.lite.accelerators.tpu import TPUAccelerator as LiteTPUAccelerator
-from lightning.lite.utilities.types import _DEVICE
+from lightning.fabric.accelerators.tpu import _parse_tpu_devices, _XLA_AVAILABLE
+from lightning.fabric.accelerators.tpu import TPUAccelerator as FabricTPUAccelerator
+from lightning.fabric.utilities.types import _DEVICE
 from lightning.pytorch.accelerators.accelerator import Accelerator
 
 
@@ -58,7 +58,7 @@ class TPUAccelerator(Accelerator):
     @staticmethod
     def parse_devices(devices: Union[int, str, List[int]]) -> Optional[Union[int, List[int]]]:
         """Accelerator device parsing logic."""
-        return _parse_tpu_cores(devices)
+        return _parse_tpu_devices(devices)
 
     @staticmethod
     def get_parallel_devices(devices: Union[int, List[int]]) -> List[int]:
@@ -74,7 +74,7 @@ class TPUAccelerator(Accelerator):
 
     @staticmethod
     def is_available() -> bool:
-        return LiteTPUAccelerator.is_available()
+        return FabricTPUAccelerator.is_available()
 
     @classmethod
     def register_accelerators(cls, accelerator_registry: Dict) -> None:
