@@ -22,18 +22,14 @@ from typing import Any, Callable, Dict, Optional, Sequence, Union
 
 import torch
 from torch import Tensor
+from torch.ao.quantization.qconfig import QConfig
 from torch.quantization import FakeQuantizeBase
 
 import lightning.pytorch as pl
+from lightning.fabric.utilities.imports import _TORCH_GREATER_EQUAL_1_11, _TORCH_GREATER_EQUAL_1_12
 from lightning.pytorch.callbacks.callback import Callback
-from lightning.pytorch.utilities import _TORCH_GREATER_EQUAL_1_10, _TORCH_GREATER_EQUAL_1_11, _TORCH_GREATER_EQUAL_1_12
 from lightning.pytorch.utilities.exceptions import MisconfigurationException
 
-if _TORCH_GREATER_EQUAL_1_10:
-    from torch.ao.quantization.qconfig import QConfig
-else:
-    from torch.quantization import QConfig
-
 if _TORCH_GREATER_EQUAL_1_11:
     from torch.ao.quantization import fuse_modules_qat as fuse_modules
 else:
@@ -155,7 +151,8 @@ class QuantizationAwareTraining(Callback):
             not be controlled by the callback.
 
     .. _PyTorch Quantization: https://pytorch.org/docs/stable/quantization.html#quantization-aware-training
-    .. _torch.quantization.QConfig: https://pytorch.org/docs/stable/torch.quantization.html#torch.quantization.QConfig
+    .. _torch.quantization.QConfig:
+        https://pytorch.org/docs/stable/generated/torch.quantization.qconfig.QConfig.html#qconfig
     """
 
     OBSERVER_TYPES = ("histogram", "average")
@@ -252,15 +249,9 @@ class QuantizationAwareTraining(Callback):
             if self._observer_type == "histogram":
                 model.qconfig = torch.quantization.get_default_qconfig(self._qconfig)
             elif self._observer_type == "average":
-                extra_kwargs: Dict[str, Optional[int]] = {}
-                if _TORCH_GREATER_EQUAL_1_12:
-                    extra_kwargs["version"] = 0
-                # version=None corresponds to using FakeQuantize rather than
-                # FusedMovingAvgObsFakeQuantize which was introduced in PT1.10
-                # details in https://github.com/pytorch/pytorch/issues/64564
-                elif _TORCH_GREATER_EQUAL_1_10:
-                    extra_kwargs["version"] = None
-                model.qconfig = torch.quantization.get_default_qat_qconfig(self._qconfig, **extra_kwargs)
+                model.qconfig = torch.quantization.get_default_qat_qconfig(
+                    self._qconfig, version=0 if _TORCH_GREATER_EQUAL_1_12 else None
+                )
 
         elif isinstance(self._qconfig, QConfig):
             model.qconfig = self._qconfig  # type: ignore [assignment]
