@@ -15,7 +15,7 @@ import os
 import sys
 from functools import partial, update_wrapper
 from types import MethodType
-from typing import Any, Callable, Dict, List, Optional, Set, Tuple, Type, Union
+from typing import Any, Callable, Dict, Iterable, List, Optional, Set, Tuple, Type, Union
 
 import torch
 from lightning_utilities.core.imports import RequirementCache
@@ -23,13 +23,14 @@ from lightning_utilities.core.rank_zero import _warn
 from torch.optim import Optimizer
 
 import lightning.pytorch as pl
-from lightning.lite.utilities.cloud_io import get_filesystem
+from lightning.fabric.utilities.cloud_io import get_filesystem
+from lightning.fabric.utilities.types import _TORCH_LRSCHEDULER
 from lightning.pytorch import Callback, LightningDataModule, LightningModule, seed_everything, Trainer
 from lightning.pytorch.utilities.exceptions import MisconfigurationException
 from lightning.pytorch.utilities.model_helpers import is_overridden
 from lightning.pytorch.utilities.rank_zero import rank_zero_deprecation, rank_zero_warn
 
-_JSONARGPARSE_SIGNATURES_AVAILABLE = RequirementCache("jsonargparse[signatures]>=4.15.2")
+_JSONARGPARSE_SIGNATURES_AVAILABLE = RequirementCache("jsonargparse[signatures]>=4.17.0")
 
 if _JSONARGPARSE_SIGNATURES_AVAILABLE:
     import docstring_parser
@@ -49,9 +50,6 @@ else:
     locals()["Namespace"] = object
 
 
-ArgsType = Optional[Union[List[str], Dict[str, Any], Namespace]]
-
-
 class ReduceLROnPlateau(torch.optim.lr_scheduler.ReduceLROnPlateau):
     def __init__(self, optimizer: Optimizer, monitor: str, *args: Any, **kwargs: Any) -> None:
         super().__init__(optimizer, *args, **kwargs)
@@ -59,25 +57,43 @@ class ReduceLROnPlateau(torch.optim.lr_scheduler.ReduceLROnPlateau):
 
 
 # LightningCLI requires the ReduceLROnPlateau defined here, thus it shouldn't accept the one from pytorch:
-LRSchedulerTypeTuple = (torch.optim.lr_scheduler._LRScheduler, ReduceLROnPlateau)
-LRSchedulerTypeUnion = Union[torch.optim.lr_scheduler._LRScheduler, ReduceLROnPlateau]
-LRSchedulerType = Union[Type[torch.optim.lr_scheduler._LRScheduler], Type[ReduceLROnPlateau]]
+LRSchedulerTypeTuple = (_TORCH_LRSCHEDULER, ReduceLROnPlateau)
+LRSchedulerTypeUnion = Union[_TORCH_LRSCHEDULER, ReduceLROnPlateau]
+LRSchedulerType = Union[Type[_TORCH_LRSCHEDULER], Type[ReduceLROnPlateau]]
+
+
+# Type aliases intended for convenience of CLI developers
+ArgsType = Optional[Union[List[str], Dict[str, Any], Namespace]]
+OptimizerCallable = Callable[[Iterable], Optimizer]
+LRSchedulerCallable = Callable[[Optimizer], Union[_TORCH_LRSCHEDULER, ReduceLROnPlateau]]
 
 
 class LightningArgumentParser(ArgumentParser):
     """Extension of jsonargparse's ArgumentParser for pytorch-lightning."""
 
-    def __init__(self, *args: Any, **kwargs: Any) -> None:
+    def __init__(
+        self,
+        *args: Any,
+        description: str = "pytorch-lightning trainer command line tool",
+        env_prefix: str = "PL",
+        default_env: bool = False,
+        **kwargs: Any,
+    ) -> None:
         """Initialize argument parser that supports configuration file input.
 
         For full details of accepted arguments see `ArgumentParser.__init__
-        <https://jsonargparse.readthedocs.io/en/stable/index.html#jsonargparse.ArgumentParser.__init__>`_.
+        <https://jsonargparse.readthedocs.io/en/stable/#jsonargparse.ArgumentParser.__init__>`_.
+
+        Args:
+            description: Description of the tool shown when running ``--help``.
+            env_prefix: Prefix for environment variables. Set ``default_env=True`` to enable env parsing.
+            default_env: Whether to parse environment variables.
         """
         if not _JSONARGPARSE_SIGNATURES_AVAILABLE:
             raise ModuleNotFoundError(
                 f"{_JSONARGPARSE_SIGNATURES_AVAILABLE}. Try `pip install -U 'jsonargparse[signatures]'`."
             )
-        super().__init__(*args, **kwargs)
+        super().__init__(*args, description=description, env_prefix=env_prefix, default_env=default_env, **kwargs)
         self.callback_keys: List[str] = []
         # separate optimizers and lr schedulers to know which were added
         self._optimizers: Dict[str, Tuple[Union[Type, Tuple[Type, ...]], str]] = {}
@@ -257,23 +273,20 @@ class LightningCLI:
         trainer_class: Union[Type[Trainer], Callable[..., Trainer]] = Trainer,
         trainer_defaults: Optional[Dict[str, Any]] = None,
         seed_everything_default: Union[bool, int] = True,
-        description: str = "pytorch-lightning trainer command line tool",
-        env_prefix: str = "PL",
-        env_parse: bool = False,
         parser_kwargs: Optional[Union[Dict[str, Any], Dict[str, Dict[str, Any]]]] = None,
         subclass_mode_model: bool = False,
         subclass_mode_data: bool = False,
         args: ArgsType = None,
         run: bool = True,
-        auto_registry: bool = False,
-        **kwargs: Any,  # Remove with deprecations of v1.10
+        auto_configure_optimizers: bool = True,
+        **kwargs: Any,  # Remove with deprecations of v2.0.0
     ) -> None:
         """Receives as input pytorch-lightning classes (or callables which return pytorch-lightning classes), which
         are called / instantiated using a parsed configuration file and / or command line args.
 
-        Parsing of configuration from environment variables can be enabled by setting ``env_parse=True``.
-        A full configuration yaml would be parsed from ``PL_CONFIG`` if set.
-        Individual settings are so parsed from variables named for example ``PL_TRAINER__MAX_EPOCHS``.
+        Parsing of configuration from environment variables can be enabled by setting ``parser_kwargs={"default_env":
+        True}``. A full configuration yaml would be parsed from ``PL_CONFIG`` if set. Individual settings are so parsed
+        from variables named for example ``PL_TRAINER__MAX_EPOCHS``.
 
         For more info, read :ref:`the CLI docs <lightning-cli>`.
 
@@ -294,12 +307,9 @@ class LightningCLI:
                 this argument will not be configurable from a configuration file and will always be present for
                 this particular CLI. Alternatively, configurable callbacks can be added as explained in
                 :ref:`the CLI docs <lightning-cli>`.
-            seed_everything_default: Number for the :func:`~lightning.lite.utilities.seed.seed_everything`
+            seed_everything_default: Number for the :func:`~lightning.fabric.utilities.seed.seed_everything`
                 seed value. Set to True to automatically choose a seed value.
                 Setting it to False will avoid calling ``seed_everything``.
-            description: Description of the tool shown when running ``--help``.
-            env_prefix: Prefix for environment variables.
-            env_parse: Whether environment variable parsing is enabled.
             parser_kwargs: Additional arguments to instantiate each ``LightningArgumentParser``.
             subclass_mode_model: Whether model can be any `subclass
                 <https://jsonargparse.readthedocs.io/en/stable/#class-type-and-sub-classes>`_
@@ -312,13 +322,14 @@ class LightningCLI:
                 ``dict`` or ``jsonargparse.Namespace``.
             run: Whether subcommands should be added to run a :class:`~lightning.pytorch.trainer.trainer.Trainer`
                 method. If set to ``False``, the trainer and model classes will be instantiated only.
-            auto_registry: Whether to automatically fill up the registries with all defined subclasses.
         """
         self.save_config_callback = save_config_callback
         self.save_config_kwargs = save_config_kwargs or {}
         self.trainer_class = trainer_class
         self.trainer_defaults = trainer_defaults or {}
         self.seed_everything_default = seed_everything_default
+        self.parser_kwargs = parser_kwargs or {}  # type: ignore[var-annotated]  # github.com/python/mypy/issues/6463
+        self.auto_configure_optimizers = auto_configure_optimizers
 
         self._handle_deprecated_params(kwargs)
 
@@ -332,14 +343,7 @@ class LightningCLI:
         self._datamodule_class = datamodule_class or LightningDataModule
         self.subclass_mode_data = (datamodule_class is None) or subclass_mode_data
 
-        from lightning.pytorch.utilities.cli import _populate_registries
-
-        _populate_registries(auto_registry)
-
-        main_kwargs, subparser_kwargs = self._setup_parser_kwargs(
-            parser_kwargs or {},  # type: ignore  # github.com/python/mypy/issues/6463
-            {"description": description, "env_prefix": env_prefix, "default_env": env_parse},
-        )
+        main_kwargs, subparser_kwargs = self._setup_parser_kwargs(self.parser_kwargs)
         self.setup_parser(run, main_kwargs, subparser_kwargs)
         self.parse_arguments(self.parser, args)
 
@@ -354,35 +358,32 @@ class LightningCLI:
             self._run_subcommand(self.subcommand)
 
     def _handle_deprecated_params(self, kwargs: dict) -> None:
-        if self.seed_everything_default is None:
+        for name in kwargs.keys() & ["save_config_filename", "save_config_overwrite", "save_config_multifile"]:
+            value = kwargs.pop(name)
+            key = name.replace("save_config_", "").replace("filename", "config_filename")
+            self.save_config_kwargs[key] = value
             rank_zero_deprecation(
-                "Setting `LightningCLI.seed_everything_default` to `None` is deprecated in v1.7 "
-                "and will be removed in v1.9. Set it to `False` instead."
+                f"LightningCLI's {name!r} init parameter is deprecated from v1.8 and will "
+                f"be removed in v2.0.0. Use `save_config_kwargs={{'{key}': ...}}` instead."
             )
-            self.seed_everything_default = False
 
-        for name in ["save_config_filename", "save_config_overwrite", "save_config_multifile"]:
-            if name in kwargs:
-                value = kwargs.pop(name)
-                key = name.replace("save_config_", "").replace("filename", "config_filename")
-                self.save_config_kwargs[key] = value
-                rank_zero_deprecation(
-                    f"LightningCLI's {name!r} init parameter is deprecated from v1.8 "
-                    "and will be removed in v1.10. Use 'save_config_kwargs' instead."
-                )
+        for name in kwargs.keys() & ["description", "env_prefix", "env_parse"]:
+            value = kwargs.pop(name)
+            key = name.replace("env_parse", "default_env")
+            self.parser_kwargs[key] = value
+            rank_zero_deprecation(
+                f"LightningCLI's {name!r} init parameter is deprecated from v1.9 and will "
+                f"be removed in v2.0. Use `parser_kwargs={{'{key}': ...}}` instead."
+            )
 
         if kwargs:
             raise ValueError(f"Unexpected keyword parameters: {kwargs}")
 
-    def _setup_parser_kwargs(
-        self, kwargs: Dict[str, Any], defaults: Dict[str, Any]
-    ) -> Tuple[Dict[str, Any], Dict[str, Any]]:
-        if kwargs.keys() & self.subcommands().keys():
-            # `kwargs` contains arguments per subcommand
-            return defaults, kwargs
-        main_kwargs = defaults
-        main_kwargs.update(kwargs)
-        return main_kwargs, {}
+    def _setup_parser_kwargs(self, parser_kwargs: Dict[str, Any]) -> Tuple[Dict[str, Any], Dict[str, Any]]:
+        subcommand_names = self.subcommands().keys()
+        main_kwargs = {k: v for k, v in parser_kwargs.items() if k not in subcommand_names}
+        subparser_kwargs = {k: v for k, v in parser_kwargs.items() if k in subcommand_names}
+        return main_kwargs, subparser_kwargs
 
     def init_parser(self, **kwargs: Any) -> LightningArgumentParser:
         """Method that instantiates the argument parser."""
@@ -438,10 +439,11 @@ class LightningCLI:
         self.add_core_arguments_to_parser(parser)
         self.add_arguments_to_parser(parser)
         # add default optimizer args if necessary
-        if not parser._optimizers:  # already added by the user in `add_arguments_to_parser`
-            parser.add_optimizer_args((Optimizer,))
-        if not parser._lr_schedulers:  # already added by the user in `add_arguments_to_parser`
-            parser.add_lr_scheduler_args(LRSchedulerTypeTuple)
+        if self.auto_configure_optimizers:
+            if not parser._optimizers:  # already added by the user in `add_arguments_to_parser`
+                parser.add_optimizer_args((Optimizer,))
+            if not parser._lr_schedulers:  # already added by the user in `add_arguments_to_parser`
+                parser.add_lr_scheduler_args(LRSchedulerTypeTuple)
         self.link_optimizers_and_lr_schedulers(parser)
 
     def add_arguments_to_parser(self, parser: LightningArgumentParser) -> None:
@@ -485,7 +487,7 @@ class LightningCLI:
         parser = self.init_parser(**kwargs)
         self._add_arguments(parser)
         # subcommand arguments
-        skip = self.subcommands()[subcommand]
+        skip: Set[Union[str, int]] = set(self.subcommands()[subcommand])
         added = parser.add_method_arguments(klass, subcommand, skip=skip)
         # need to save which arguments were added to pass them to the method later
         self._subcommand_method_arguments[subcommand] = added
@@ -593,6 +595,9 @@ class LightningCLI:
     def _add_configure_optimizers_method_to_model(self, subcommand: Optional[str]) -> None:
         """Overrides the model's :meth:`~lightning.pytorch.core.module.LightningModule.configure_optimizers` method
         if a single optimizer and optionally a scheduler argument groups are added to the parser as 'AUTOMATIC'."""
+        if not self.auto_configure_optimizers:
+            return
+
         parser = self._parser(subcommand)
 
         def get_automatic(
