@@ -20,7 +20,7 @@ from torch.utils.data import DataLoader, Dataset, IterableDataset
 from typing_extensions import Self
 
 import lightning.pytorch as pl
-from lightning.lite.utilities.types import _PATH
+from lightning.fabric.utilities.types import _PATH
 from lightning.pytorch.core.hooks import DataHooks
 from lightning.pytorch.core.mixins import HyperparametersMixin
 from lightning.pytorch.core.saving import _load_from_checkpoint
