@@ -12,5 +12,5 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from lightning.lite.utilities.device_dtype_mixin import _DeviceDtypeModuleMixin  # noqa: F401
+from lightning.fabric.utilities.device_dtype_mixin import _DeviceDtypeModuleMixin  # noqa: F401
 from lightning.pytorch.core.mixins.hparams_mixin import HyperparametersMixin  # noqa: F401
