@@ -25,19 +25,22 @@ from typing import Any, Callable, Dict, Generator, List, Mapping, Optional, over
 
 import torch
 from lightning_utilities.core.apply_func import apply_to_collection
-from lightning_utilities.core.rank_zero import WarningCache
 from torch import ScriptModule, Tensor
 from torch.nn import Module
 from torch.optim.optimizer import Optimizer
-from torchmetrics import Metric
+from torchmetrics import Metric, MetricCollection
 from typing_extensions import Literal
 
+import lightning.fabric as lf
 import lightning.pytorch as pl
-from lightning.lite.utilities.apply_func import convert_to_tensors
-from lightning.lite.utilities.cloud_io import get_filesystem
-from lightning.lite.utilities.device_dtype_mixin import _DeviceDtypeModuleMixin
-from lightning.lite.utilities.distributed import _distributed_available, _sync_ddp
-from lightning.lite.utilities.types import Steppable
+from lightning.fabric.loggers import Logger as FabricLogger
+from lightning.fabric.utilities.apply_func import convert_to_tensors
+from lightning.fabric.utilities.cloud_io import get_filesystem
+from lightning.fabric.utilities.device_dtype_mixin import _DeviceDtypeModuleMixin
+from lightning.fabric.utilities.distributed import _distributed_available, _sync_ddp
+from lightning.fabric.utilities.imports import _IS_WINDOWS, _TORCH_GREATER_EQUAL_1_11
+from lightning.fabric.utilities.types import Steppable
+from lightning.fabric.wrappers import _FabricOptimizer
 from lightning.pytorch.callbacks.callback import Callback
 from lightning.pytorch.core.hooks import CheckpointHooks, DataHooks, ModelHooks
 from lightning.pytorch.core.mixins import HyperparametersMixin
@@ -45,10 +48,10 @@ from lightning.pytorch.core.optimizer import LightningOptimizer
 from lightning.pytorch.core.saving import ModelIO
 from lightning.pytorch.loggers import Logger
 from lightning.pytorch.trainer.connectors.logger_connector.fx_validator import _FxValidator
-from lightning.pytorch.utilities import _IS_WINDOWS, _TORCH_GREATER_EQUAL_1_10, GradClipAlgorithmType
+from lightning.pytorch.utilities import GradClipAlgorithmType
 from lightning.pytorch.utilities.exceptions import MisconfigurationException
-from lightning.pytorch.utilities.imports import _TORCH_GREATER_EQUAL_1_11, _TORCH_GREATER_EQUAL_1_13
-from lightning.pytorch.utilities.rank_zero import rank_zero_debug, rank_zero_warn
+from lightning.pytorch.utilities.imports import _TORCH_GREATER_EQUAL_1_13, _TORCHMETRICS_GREATER_EQUAL_0_9_1
+from lightning.pytorch.utilities.rank_zero import rank_zero_debug, rank_zero_warn, WarningCache
 from lightning.pytorch.utilities.signature_utils import is_param_in_hook_signature
 from lightning.pytorch.utilities.types import (
     _METRIC_COLLECTION,
@@ -61,7 +64,9 @@ from lightning.pytorch.utilities.types import (
 warning_cache = WarningCache()
 log = logging.getLogger(__name__)
 
-MODULE_OPTIMIZERS = Union[Optimizer, LightningOptimizer, List[Optimizer], List[LightningOptimizer]]
+MODULE_OPTIMIZERS = Union[
+    Optimizer, LightningOptimizer, _FabricOptimizer, List[Optimizer], List[LightningOptimizer], List[_FabricOptimizer]
+]
 
 
 class LightningModule(
@@ -75,7 +80,7 @@ class LightningModule(
 ):
     # Below is for property support of JIT
     # since none of these are important when using JIT, we are going to ignore them.
-    __jit_unused_properties__ = (
+    __jit_unused_properties__: List[str] = (
         [
             "example_input_array",
             "on_gpu",
@@ -88,6 +93,7 @@ class LightningModule(
             "automatic_optimization",
             "truncated_bptt_steps",
             "trainer",
+            "fabric",
         ]
         + _DeviceDtypeModuleMixin.__jit_unused_properties__
         + HyperparametersMixin.__jit_unused_properties__
@@ -118,6 +124,10 @@ class LightningModule(
         self._register_sharded_tensor_state_dict_hooks_if_available()
         self._compiler_ctx: Optional[Dict[str, Any]] = None
 
+        # attributes only used when using fabric
+        self._fabric: Optional["lf.Fabric"] = None
+        self._fabric_optimizers: List[_FabricOptimizer] = []
+
     @overload
     def optimizers(self, use_pl_optimizer: Literal[True] = True) -> Union[LightningOptimizer, List[LightningOptimizer]]:
         ...
@@ -141,13 +151,19 @@ class LightningModule(
         Returns:
             A single optimizer, or a list of optimizers in case multiple ones are present.
         """
-        if use_pl_optimizer:
-            opts: MODULE_OPTIMIZERS = list(self.trainer.strategy._lightning_optimizers.values())
+        if self._fabric:
+            opts: MODULE_OPTIMIZERS = self._fabric_optimizers
+        elif use_pl_optimizer:
+            opts = list(self.trainer.strategy._lightning_optimizers.values())
         else:
             opts = self.trainer.optimizers
 
         # single optimizer
-        if isinstance(opts, list) and len(opts) == 1 and isinstance(opts[0], (Optimizer, LightningOptimizer)):
+        if (
+            isinstance(opts, list)
+            and len(opts) == 1
+            and isinstance(opts[0], (Optimizer, LightningOptimizer, _FabricOptimizer))
+        ):
             return opts[0]
         # multiple opts
         return opts
@@ -175,6 +191,8 @@ class LightningModule(
 
     @property
     def trainer(self) -> "pl.Trainer":
+        if self._fabric is not None:
+            return _TrainerFabricShim(fabric=self._fabric)  # type: ignore[return-value]
         if not self._jit_is_scripting and self._trainer is None:
             raise RuntimeError(f"{self.__class__.__qualname__} is not attached to a `Trainer`.")
         return self._trainer  # type: ignore[return-value]
@@ -188,6 +206,19 @@ class LightningModule(
             trainer = weakref.proxy(trainer)
         self._trainer = trainer
 
+    @property
+    def fabric(self) -> Optional["lf.Fabric"]:
+        return self._fabric
+
+    @fabric.setter
+    def fabric(self, fabric: Optional["lf.Fabric"]) -> None:
+        for v in self.children():
+            if isinstance(v, LightningModule):
+                v.fabric = fabric
+        if fabric is not None and not isinstance(fabric, weakref.ProxyTypes):
+            fabric = weakref.proxy(fabric)
+        self._fabric = fabric
+
     @property
     def example_input_array(self) -> Optional[Union[Tensor, Tuple, Dict]]:
         """The example input array is a specification of what the module can consume in the :meth:`forward` method.
@@ -261,14 +292,20 @@ class LightningModule(
         self._truncated_bptt_steps = truncated_bptt_steps
 
     @property
-    def logger(self) -> Optional[Logger]:
+    def logger(self) -> Optional[Union[Logger, FabricLogger]]:
         """Reference to the logger object in the Trainer."""
+        if self._fabric is not None:
+            return self._fabric.logger
         return self._trainer.logger if self._trainer is not None else None
 
     @property
-    def loggers(self) -> List[Logger]:
+    def loggers(self) -> Union[List[Logger], List[FabricLogger]]:
         """Reference to the list of loggers in the Trainer."""
-        return self.trainer.loggers if self._trainer else []
+        if self._fabric is not None:
+            return self._fabric.loggers
+        elif self._trainer is not None:
+            return self._trainer.loggers
+        return []  # type: ignore[return-value]
 
     def _call_batch_hook(self, hook_name: str, *args: Any) -> Any:
         if self._trainer:
@@ -322,7 +359,7 @@ class LightningModule(
         name: str,
         value: _METRIC_COLLECTION,
         prog_bar: bool = False,
-        logger: bool = True,
+        logger: Optional[bool] = None,
         on_step: Optional[bool] = None,
         on_epoch: Optional[bool] = None,
         reduce_fx: Union[str, Callable] = "mean",
@@ -366,6 +403,10 @@ class LightningModule(
             rank_zero_only: Whether the value will be logged only on rank 0. This will prevent synchronization which
                 would produce a deadlock as not all processes would perform this log call.
         """
+        if self._fabric is not None:
+            self._log_dict_through_fabric(dictionary={name: value}, logger=logger)
+            return
+
         # check for invalid values
         apply_to_collection(value, dict, self.__check_not_nested, name)
         apply_to_collection(
@@ -402,7 +443,7 @@ class LightningModule(
                 " but it should not contain information about `dataloader_idx`"
             )
 
-        value = apply_to_collection(value, (torch.Tensor, numbers.Number), self.__to_tensor, name)
+        value = apply_to_collection(value, (Tensor, numbers.Number), self.__to_tensor, name)
 
         if self.trainer._logger_connector.should_reset_tensors(self._current_fx_name):
             # if we started a new epoch (running its first batch) the hook name has changed
@@ -438,6 +479,16 @@ class LightningModule(
                 "With `def training_step(self, dataloader_iter)`, `self.log(..., batch_size=...)` should be provided."
             )
 
+        if logger and self.trainer.logger is None:
+            rank_zero_warn(
+                f"You called `self.log({name!r}, ..., logger=True)` but have no logger configured. You can enable one"
+                " by doing `Trainer(logger=ALogger(...))`"
+            )
+        if logger is None:
+            # we could set false here if there's no configured logger, however, we still need to compute the "logged"
+            # metrics anyway because that's what the evaluation loops use as return value
+            logger = True
+
         results.log(
             self._current_fx_name,
             name,
@@ -463,7 +514,7 @@ class LightningModule(
         self,
         dictionary: Mapping[str, _METRIC_COLLECTION],
         prog_bar: bool = False,
-        logger: bool = True,
+        logger: Optional[bool] = None,
         on_step: Optional[bool] = None,
         on_epoch: Optional[bool] = None,
         reduce_fx: Union[str, Callable] = "mean",
@@ -483,7 +534,8 @@ class LightningModule(
 
         Args:
             dictionary: key value pairs.
-                The values can be a ``float``, ``Tensor``, ``Metric``, or a dictionary of the former.
+                The values can be a ``float``, ``Tensor``, ``Metric``, a dictionary of the former
+                or a ``MetricCollection``.
             prog_bar: if ``True`` logs to the progress base.
             logger: if ``True`` logs to the logger.
             on_step: if ``True`` logs at this step.
@@ -507,7 +559,17 @@ class LightningModule(
             rank_zero_only: Whether the value will be logged only on rank 0. This will prevent synchronization which
                 would produce a deadlock as not all processes would perform this log call.
         """
-        for k, v in dictionary.items():
+        if self._fabric is not None:
+            return self._log_dict_through_fabric(dictionary=dictionary, logger=logger)
+
+        kwargs: Dict[str, bool] = {}
+
+        if isinstance(dictionary, MetricCollection):
+            kwargs["keep_base"] = False
+            if _TORCHMETRICS_GREATER_EQUAL_0_9_1 and dictionary._enable_compute_groups:
+                kwargs["copy_state"] = False
+
+        for k, v in dictionary.items(**kwargs):
             self.log(
                 name=k,
                 value=v,
@@ -524,6 +586,20 @@ class LightningModule(
                 rank_zero_only=rank_zero_only,
             )
 
+    def _log_dict_through_fabric(self, dictionary: Mapping[str, Any], logger: Optional[bool] = None) -> None:
+        if logger is False:
+            # Passing `logger=False` with Fabric does not make much sense because there is no other destination to
+            # log to, but we support it in case the original code was written for Trainer use
+            return
+
+        if any(isinstance(v, dict) for v in dictionary.values()):
+            raise ValueError(f"`self.log_dict({dictionary})` was called, but nested dictionaries cannot be logged")
+        for name, value in dictionary.items():
+            apply_to_collection(value, object, self.__check_allowed, name, value, wrong_dtype=(numbers.Number, Tensor))
+
+        assert self._fabric is not None
+        self._fabric.log_dict(metrics=dictionary)
+
     @staticmethod
     def __check_not_nested(value: dict, name: str) -> None:
         # self-imposed restriction. for simplicity
@@ -534,10 +610,10 @@ class LightningModule(
     def __check_allowed(v: Any, name: str, value: Any) -> None:
         raise ValueError(f"`self.log({name}, {value})` was called, but `{type(v).__name__}` values cannot be logged")
 
-    def __to_tensor(self, value: Union[torch.Tensor, numbers.Number], name: str) -> Tensor:
+    def __to_tensor(self, value: Union[Tensor, numbers.Number], name: str) -> Tensor:
         value = (
             value.clone().detach().to(self.device)
-            if isinstance(value, torch.Tensor)
+            if isinstance(value, Tensor)
             else torch.tensor(value, device=self.device)
         )
         if not torch.numel(value) == 1:
@@ -1383,8 +1459,11 @@ class LightningModule(
             *args: Additional positional arguments to be forwarded to :meth:`~torch.Tensor.backward`
             **kwargs: Additional keyword arguments to be forwarded to :meth:`~torch.Tensor.backward`
         """
-        self._verify_is_manual_optimization("manual_backward")
-        self.trainer.strategy.backward(loss, None, None, *args, **kwargs)
+        if self._fabric:
+            self._fabric.backward(loss, *args, **kwargs)
+        else:
+            self._verify_is_manual_optimization("manual_backward")
+            self.trainer.strategy.backward(loss, None, None, *args, **kwargs)
 
     def backward(
         self, loss: Tensor, optimizer: Optional[Steppable], optimizer_idx: Optional[int], *args: Any, **kwargs: Any
@@ -1403,7 +1482,10 @@ class LightningModule(
             def backward(self, loss, optimizer, optimizer_idx):
                 loss.backward()
         """
-        loss.backward(*args, **kwargs)
+        if self._fabric:
+            self._fabric.backward(loss, *args, **kwargs)
+        else:
+            loss.backward(*args, **kwargs)
 
     def toggle_optimizer(self, optimizer: Union[Optimizer, LightningOptimizer], optimizer_idx: int) -> None:
         """Makes sure only the gradients of the current optimizer's parameters are calculated in the training step
@@ -1461,8 +1543,12 @@ class LightningModule(
         """Handles gradient clipping internally.
 
         Note:
-            Do not override this method. If you want to customize gradient clipping, consider
-            using :meth:`configure_gradient_clipping` method.
+            - Do not override this method. If you want to customize gradient clipping, consider using
+              :meth:`configure_gradient_clipping` method.
+            - For manual optimization (``self.automatic_optimization = False``), if you want to use
+              gradient clipping, consider calling
+              ``self.clip_gradients(opt, gradient_clip_val=0.5, gradient_clip_algorithm="norm")``
+              manually in the training step.
 
         Args:
             optimizer: Current optimizer being used.
@@ -1584,7 +1670,6 @@ class LightningModule(
         optimizer_idx: int = 0,
         optimizer_closure: Optional[Callable[[], Any]] = None,
         on_tpu: bool = False,
-        using_native_amp: bool = False,
         using_lbfgs: bool = False,
     ) -> None:
         r"""
@@ -1603,19 +1688,18 @@ class LightningModule(
             optimizer_closure: The optimizer closure. This closure must be executed as it includes the
                 calls to ``training_step()``, ``optimizer.zero_grad()``, and ``backward()``.
             on_tpu: ``True`` if TPU backward is required
-            using_native_amp: ``True`` if using native amp
             using_lbfgs: True if the matching optimizer is :class:`torch.optim.LBFGS`
 
         Examples::
 
             # DEFAULT
             def optimizer_step(self, epoch, batch_idx, optimizer, optimizer_idx,
-                               optimizer_closure, on_tpu, using_native_amp, using_lbfgs):
+                               optimizer_closure, on_tpu, using_lbfgs):
                 optimizer.step(closure=optimizer_closure)
 
             # Alternating schedule for optimizer steps (i.e.: GANs)
             def optimizer_step(self, epoch, batch_idx, optimizer, optimizer_idx,
-                               optimizer_closure, on_tpu, using_native_amp, using_lbfgs):
+                               optimizer_closure, on_tpu, using_lbfgs):
                 # update generator opt every step
                 if optimizer_idx == 0:
                     optimizer.step(closure=optimizer_closure)
@@ -1645,7 +1729,6 @@ class LightningModule(
                 optimizer_idx,
                 optimizer_closure,
                 on_tpu,
-                using_native_amp,
                 using_lbfgs,
             ):
                 # update params
@@ -1732,7 +1815,7 @@ class LightningModule(
                 split_x: Union[Tensor, List[Tensor]]
                 if isinstance(x, Tensor):
                     split_x = x[:, t : t + split_size]
-                elif isinstance(x, collections.Sequence):
+                elif isinstance(x, collections.abc.Sequence):
                     split_x = [x[batch_idx][t : t + split_size] for batch_idx in range(len(x))]
 
                 batch_split.append(split_x)
@@ -1814,13 +1897,6 @@ class LightningModule(
         input_sample = self._on_before_batch_transfer(input_sample)
         input_sample = self._apply_batch_transfer_handler(input_sample)
 
-        if not _TORCH_GREATER_EQUAL_1_10 and "example_outputs" not in kwargs:
-            self.eval()
-            if isinstance(input_sample, tuple):
-                kwargs["example_outputs"] = self(*input_sample)
-            else:
-                kwargs["example_outputs"] = self(input_sample)
-
         torch.onnx.export(self, input_sample, file_path, **kwargs)
         self.train(mode)
 
@@ -1928,7 +2004,7 @@ class LightningModule(
 
         These hooks ensure that ShardedTensors are included when saving, and are loaded the LightningModule correctly.
         """
-        if not _TORCH_GREATER_EQUAL_1_10 or _IS_WINDOWS or not torch.distributed.is_available():
+        if _IS_WINDOWS or not torch.distributed.is_available():
             rank_zero_debug("Could not register sharded tensor state dict hooks")
             return
 
@@ -2032,3 +2108,20 @@ def _jit_is_scripting() -> Generator:
         yield
     finally:
         LightningModule._jit_is_scripting = False
+
+
+class _TrainerFabricShim:
+    """Intercepts attribute access on LightningModule's trainer reference and redirects it to the Fabric object."""
+
+    def __init__(self, fabric: lf.Fabric) -> None:
+        super().__init__()
+        self._fabric = fabric
+
+    def __getattr__(self, item: Any) -> Any:
+        try:
+            return getattr(self._fabric, item)
+        except AttributeError:
+            raise AttributeError(
+                f"Your LightningModule code tried to access `self.trainer.{item}` but this attribute is not available"
+                f" when using Fabric with a LightningModule."
+            )
