@@ -13,8 +13,6 @@
 # limitations under the License.
 import os
 
-# LightningLoggerBase imported for backward compatibility
-from lightning.pytorch.loggers.base import LightningLoggerBase
 from lightning.pytorch.loggers.comet import _COMET_AVAILABLE, CometLogger  # noqa: F401
 from lightning.pytorch.loggers.csv_logs import CSVLogger
 from lightning.pytorch.loggers.logger import Logger
@@ -23,7 +21,7 @@ from lightning.pytorch.loggers.neptune import NeptuneLogger  # noqa: F401
 from lightning.pytorch.loggers.tensorboard import TensorBoardLogger
 from lightning.pytorch.loggers.wandb import WandbLogger  # noqa: F401
 
-__all__ = ["CSVLogger", "LightningLoggerBase", "Logger", "TensorBoardLogger"]
+__all__ = ["CSVLogger", "Logger", "TensorBoardLogger"]
 
 if _COMET_AVAILABLE:
     __all__.append("CometLogger")
