@@ -16,7 +16,6 @@ from functools import partial
 from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
 import torch
-from lightning_utilities.core.rank_zero import WarningCache
 from torch import Tensor
 from torch.optim import Optimizer
 from typing_extensions import OrderedDict
@@ -30,9 +29,12 @@ from lightning.pytorch.loops.utilities import (
     _build_training_step_kwargs,
     _extract_hiddens,
 )
+from lightning.pytorch.plugins import ApexMixedPrecisionPlugin
+from lightning.pytorch.plugins.precision.native_amp import MixedPrecisionPlugin
 from lightning.pytorch.trainer.progress import OptimizationProgress
-from lightning.pytorch.utilities import AMPType
 from lightning.pytorch.utilities.exceptions import MisconfigurationException
+from lightning.pytorch.utilities.rank_zero import rank_zero_deprecation, WarningCache
+from lightning.pytorch.utilities.signature_utils import is_param_in_hook_signature
 from lightning.pytorch.utilities.types import STEP_OUTPUT
 
 
@@ -341,7 +343,7 @@ class OptimizerLoop(Loop[_OUTPUTS_TYPE]):
         is_lbfgs = isinstance(optimizer, torch.optim.LBFGS)
 
         # wraps into LightningOptimizer only for running step
-        if self.trainer.amp_backend == AMPType.APEX:
+        if isinstance(self.trainer.precision_plugin, ApexMixedPrecisionPlugin):
             # apex overrides .step function and need to be wrapped on each step
             optimizer = LightningOptimizer._to_lightning_optimizer(optimizer, self.trainer.strategy, opt_idx)
         else:
@@ -354,6 +356,17 @@ class OptimizerLoop(Loop[_OUTPUTS_TYPE]):
             self.optim_progress.optimizer.step.increment_ready()
 
         # model hook
+        kwargs = {}
+        pl_module = self.trainer.lightning_module
+        if is_param_in_hook_signature(pl_module.optimizer_step, "using_native_amp", explicit=True):
+            rank_zero_deprecation(
+                "The NVIDIA/apex AMP implementation has been deprecated upstream. Consequently, its integration inside"
+                " PyTorch Lightning has been deprecated in v1.9.0 and will be removed in v2.0.0."
+                f" The `{type(pl_module).__name__}.optimizer_step()` hook is overridden, including the"
+                " `using_native_amp` argument. Removing this argument will avoid this message, you can expect it to"
+                " return True."
+            )
+            kwargs["using_native_amp"] = isinstance(self.trainer.precision_plugin, MixedPrecisionPlugin)
         self.trainer._call_lightning_module_hook(
             "optimizer_step",
             self.trainer.current_epoch,
@@ -362,7 +375,7 @@ class OptimizerLoop(Loop[_OUTPUTS_TYPE]):
             opt_idx,
             train_step_and_backward_closure,
             on_tpu=isinstance(self.trainer.accelerator, TPUAccelerator),
-            using_native_amp=(self.trainer.amp_backend == AMPType.NATIVE),
+            **kwargs,  # type: ignore[arg-type]
             using_lbfgs=is_lbfgs,
         )
 
