@@ -21,10 +21,10 @@ from torch import Tensor
 from torch.nn import Module
 
 import lightning.pytorch as pl
-from lightning.lite.plugins import CheckpointIO, ClusterEnvironment
-from lightning.lite.utilities.optimizer import _optimizers_to_device
-from lightning.lite.utilities.seed import reset_seed
-from lightning.lite.utilities.types import ReduceOp
+from lightning.fabric.plugins import CheckpointIO, ClusterEnvironment
+from lightning.fabric.utilities.optimizer import _optimizers_to_device
+from lightning.fabric.utilities.seed import reset_seed
+from lightning.fabric.utilities.types import ReduceOp
 from lightning.pytorch.overrides.base import _LightningModuleWrapperBase, _LightningPrecisionModuleWrapperBase
 from lightning.pytorch.plugins.precision import PrecisionPlugin
 from lightning.pytorch.strategies.ddp import DDPStrategy
