@@ -27,13 +27,13 @@ from torch import Tensor
 from typing_extensions import Literal
 
 import lightning.pytorch as pl
-from lightning.lite.strategies.launchers.base import _Launcher
-from lightning.lite.strategies.launchers.multiprocessing import _check_bad_cuda_fork
-from lightning.lite.utilities import move_data_to_device
-from lightning.lite.utilities.seed import _collect_rng_states, _set_rng_states
-from lightning.lite.utilities.types import _PATH
+from lightning.fabric.strategies.launchers.base import _Launcher
+from lightning.fabric.strategies.launchers.multiprocessing import _check_bad_cuda_fork
+from lightning.fabric.utilities import move_data_to_device
+from lightning.fabric.utilities.imports import _TORCH_GREATER_EQUAL_1_11
+from lightning.fabric.utilities.seed import _collect_rng_states, _set_rng_states
+from lightning.fabric.utilities.types import _PATH
 from lightning.pytorch.trainer.states import TrainerFn, TrainerState
-from lightning.pytorch.utilities.imports import _TORCH_GREATER_EQUAL_1_11
 from lightning.pytorch.utilities.rank_zero import rank_zero_debug
 
 
