@@ -13,16 +13,14 @@
 # limitations under the License.
 import os
 import subprocess
-from time import sleep
 from typing import Any, Callable, Optional
 
-import numpy as np
 from lightning_utilities.core.imports import RequirementCache
 
 import lightning.pytorch as pl
-from lightning.lite.plugins import ClusterEnvironment
-from lightning.lite.strategies.launchers.base import _Launcher
-from lightning.lite.strategies.launchers.subprocess_script import _basic_subprocess_cmd, _hydra_subprocess_cmd
+from lightning.fabric.plugins import ClusterEnvironment
+from lightning.fabric.strategies.launchers.base import _Launcher
+from lightning.fabric.strategies.launchers.subprocess_script import _basic_subprocess_cmd, _hydra_subprocess_cmd
 
 _HYDRA_AVAILABLE = RequirementCache("hydra-core")
 
@@ -124,11 +122,6 @@ class _SubprocessScriptLauncher(_Launcher):
 
             subprocess.Popen(command, env=env_copy, cwd=cwd)
 
-            # starting all processes at once can cause issues
-            # with dataloaders delay between 1-10 seconds
-            delay = np.random.uniform(1, 5, 1)[0]
-            sleep(delay)
-
     def _check_can_spawn_children(self) -> None:
         if self.cluster_environment.local_rank() != 0:
             raise RuntimeError(
