@@ -23,12 +23,12 @@ from torch.optim import Optimizer
 from torch.utils.data import DataLoader
 
 import lightning.pytorch as pl
-from lightning.lite.plugins import CheckpointIO
-from lightning.lite.strategies.launchers.base import _Launcher
-from lightning.lite.utilities import move_data_to_device
-from lightning.lite.utilities.distributed import ReduceOp
-from lightning.lite.utilities.optimizer import _optimizer_to_device, _optimizers_to_device
-from lightning.lite.utilities.types import _PATH
+from lightning.fabric.plugins import CheckpointIO
+from lightning.fabric.strategies.launchers.base import _Launcher
+from lightning.fabric.utilities import move_data_to_device
+from lightning.fabric.utilities.distributed import ReduceOp
+from lightning.fabric.utilities.optimizer import _optimizer_to_device, _optimizers_to_device
+from lightning.fabric.utilities.types import _PATH
 from lightning.pytorch.core.optimizer import _init_optimizers_and_lr_schedulers, LightningOptimizer
 from lightning.pytorch.plugins import TorchCheckpointIO
 from lightning.pytorch.plugins.io.wrapper import _WrappingCheckpointIO
@@ -174,7 +174,7 @@ class Strategy(ABC):
             optimizer = optimizer._optimizer
 
         if hasattr(optimizer, "consolidate_state_dict"):
-            # there are optimizers like Fairscale's OSS or PyTorch's ZeroRedundancyOptimizer that shard their
+            # there are optimizers like PyTorch's ZeroRedundancyOptimizer that shard their
             # states, and to avoid OOM we consolidate the full state on rank 0 only
             optimizer.consolidate_state_dict()
             return optimizer.state_dict() if self.is_global_zero else {}
@@ -229,7 +229,7 @@ class Strategy(ABC):
             \**kwargs: Keyword arguments to to ``optimizer.step``
         """
         model = model or self.lightning_module
-        # TODO(lite): remove assertion once strategy's optimizer_step typing is fixed
+        # TODO(fabric): remove assertion once strategy's optimizer_step typing is fixed
         assert isinstance(model, pl.LightningModule)
         return self.precision_plugin.optimizer_step(
             optimizer, model=model, optimizer_idx=opt_idx, closure=closure, **kwargs
@@ -241,19 +241,19 @@ class Strategy(ABC):
         The returned objects are expected to be in the same order they were passed in. The default implementation will
         call :meth:`_setup_model` and :meth:`_setup_optimizer` on the inputs.
         """
-        # TODO: standardize this across all plugins in Lightning and Lite. Related refactor: #7324
+        # TODO: standardize this across all plugins in Lightning and Fabric. Related refactor: #7324
         model = self._setup_model(model)
         optimizers = [self._setup_optimizer(optimizer) for optimizer in optimizers]
         return model, optimizers
 
     def _setup_model(self, model: Module) -> Module:
         """Performs setup for the model, e.g., by wrapping it by another class."""
-        # TODO: standardize this across all plugins in Lightning and Lite. Related refactor: #7324
+        # TODO: standardize this across all plugins in Lightning and Fabric. Related refactor: #7324
         return model
 
     def _setup_optimizer(self, optimizer: Optimizer) -> Optimizer:
         """Performs setup for the optimizer, e.g., by wrapping it by another class."""
-        # TODO: standardize this across all plugins in Lightning and Lite. Related refactor: #7324
+        # TODO: standardize this across all plugins in Lightning and Fabric. Related refactor: #7324
         return optimizer
 
     def batch_to_device(self, batch: Any, device: Optional[torch.device] = None, dataloader_idx: int = 0) -> Any:
@@ -330,7 +330,7 @@ class Strategy(ABC):
             sync_grads: flag that allows users to synchronize gradients for all_gather op
         """
 
-    def reduce_boolean_decision(self, decision: bool) -> bool:
+    def reduce_boolean_decision(self, decision: bool, all: bool = True) -> bool:
         """Reduce a boolean decision across all processes."""
         return decision
 
