@@ -17,20 +17,19 @@ from typing import Any, Callable, cast, Dict, Generator, List, Optional, Tuple,
 
 import torch
 from lightning_utilities.core.apply_func import apply_to_collection, apply_to_collections
-from lightning_utilities.core.rank_zero import WarningCache
 from torch import Tensor
 from torchmetrics import Metric
 from typing_extensions import TypedDict
 
-from lightning.lite.utilities import move_data_to_device
-from lightning.lite.utilities.device_dtype_mixin import _DeviceDtypeModuleMixin
-from lightning.lite.utilities.distributed import _distributed_available
+from lightning.fabric.utilities import move_data_to_device
+from lightning.fabric.utilities.apply_func import convert_tensors_to_scalars
+from lightning.fabric.utilities.device_dtype_mixin import _DeviceDtypeModuleMixin
+from lightning.fabric.utilities.distributed import _distributed_available
 from lightning.pytorch.utilities.data import extract_batch_size
 from lightning.pytorch.utilities.exceptions import MisconfigurationException
 from lightning.pytorch.utilities.imports import _fault_tolerant_training
 from lightning.pytorch.utilities.memory import recursive_detach
-from lightning.pytorch.utilities.metrics import metrics_to_scalars
-from lightning.pytorch.utilities.rank_zero import rank_zero_warn
+from lightning.pytorch.utilities.rank_zero import rank_zero_warn, WarningCache
 from lightning.pytorch.utilities.warnings import PossibleUserWarning
 
 _IN_METRIC = Union[Metric, Tensor]  # Do not include scalars as they were converted to tensors
@@ -611,7 +610,7 @@ class _ResultCollection(dict):
 
             # populate progress_bar metrics. convert tensors to numbers
             if result_metric.meta.prog_bar:
-                metrics["pbar"][forked_name] = metrics_to_scalars(value)
+                metrics["pbar"][forked_name] = convert_tensors_to_scalars(value)
 
         return metrics
 
