@@ -18,11 +18,12 @@ from typing import Any, Callable, Dict, Iterable, Iterator, List, Mapping, Optio
 
 import torch
 from lightning_utilities.core.apply_func import apply_to_collection, apply_to_collections
+from torch import Tensor
 from torch.utils.data import Dataset
 from torch.utils.data.dataloader import _BaseDataLoaderIter, _MultiProcessingDataLoaderIter, DataLoader
 from torch.utils.data.dataset import IterableDataset
 
-from lightning.lite.utilities.distributed import _distributed_available
+from lightning.fabric.utilities.distributed import _distributed_available
 from lightning.pytorch.utilities.auto_restart import (
     _reload_dataloader_state_dict,
     MergedIteratorState,
@@ -59,18 +60,18 @@ class TensorRunningAccum:
         """Empty the accumulator."""
         if window_length is not None:
             self.window_length = window_length
-        self.memory: Optional[torch.Tensor] = None
+        self.memory: Optional[Tensor] = None
         self.current_idx: int = 0
         self.last_idx: Optional[int] = None
         self.rotated: bool = False
 
-    def last(self) -> Optional[torch.Tensor]:
+    def last(self) -> Optional[Tensor]:
         """Get the last added element."""
         if self.last_idx is not None:
-            assert isinstance(self.memory, torch.Tensor)
+            assert isinstance(self.memory, Tensor)
             return self.memory[self.last_idx].float()
 
-    def append(self, x: torch.Tensor) -> None:
+    def append(self, x: Tensor) -> None:
         """Add an element to the accumulator."""
         if self.memory is None:
             # tradeoff memory for speed by keeping the memory on device
@@ -89,21 +90,21 @@ class TensorRunningAccum:
         if self.current_idx == 0:
             self.rotated = True
 
-    def mean(self) -> Optional[torch.Tensor]:
+    def mean(self) -> Optional[Tensor]:
         """Get mean value from stored elements."""
         return self._agg_memory("mean")
 
-    def max(self) -> Optional[torch.Tensor]:
+    def max(self) -> Optional[Tensor]:
         """Get maximal value from stored elements."""
         return self._agg_memory("max")
 
-    def min(self) -> Optional[torch.Tensor]:
+    def min(self) -> Optional[Tensor]:
         """Get minimal value from stored elements."""
         return self._agg_memory("min")
 
-    def _agg_memory(self, how: str) -> Optional[torch.Tensor]:
+    def _agg_memory(self, how: str) -> Optional[Tensor]:
         if self.last_idx is not None:
-            assert isinstance(self.memory, torch.Tensor)
+            assert isinstance(self.memory, Tensor)
             if self.rotated:
                 return getattr(self.memory.float(), how)()
             return getattr(self.memory[: self.current_idx].float(), how)()
