@@ -17,7 +17,6 @@ from typing import Any, Dict, Generator, Iterable, Mapping, Optional, Tuple, Uni
 
 import torch
 from lightning_utilities.core.apply_func import is_dataclass_instance
-from lightning_utilities.core.rank_zero import WarningCache
 from torch import Tensor
 from torch.utils.data import (
     BatchSampler,
@@ -30,16 +29,16 @@ from torch.utils.data import (
 )
 
 import lightning.pytorch as pl
-from lightning.lite.utilities.data import _reinstantiate_wrapped_cls, _replace_value_in_saved_args
-from lightning.lite.utilities.data import has_iterable_dataset as new_has_iterable_dataset
-from lightning.lite.utilities.data import has_len as new_has_len
+from lightning.fabric.utilities.data import _reinstantiate_wrapped_cls, _replace_value_in_saved_args
+from lightning.fabric.utilities.data import has_iterable_dataset as new_has_iterable_dataset
+from lightning.fabric.utilities.data import has_len as new_has_len
 from lightning.pytorch.overrides.distributed import IndexBatchSamplerWrapper
 from lightning.pytorch.trainer.states import RunningStage
 from lightning.pytorch.trainer.supporters import CombinedLoader
 from lightning.pytorch.utilities.auto_restart import CaptureIterableDataset, CaptureMapDataset, FastForwardSampler
 from lightning.pytorch.utilities.enums import _FaultTolerantMode
 from lightning.pytorch.utilities.exceptions import MisconfigurationException
-from lightning.pytorch.utilities.rank_zero import rank_zero_deprecation, rank_zero_warn
+from lightning.pytorch.utilities.rank_zero import rank_zero_deprecation, rank_zero_warn, WarningCache
 
 # might be supported in later releases, see https://github.com/python/mypy/pull/13297
 BType = Union[Tensor, str, Mapping[Any, "BType"], Iterable["BType"]]  # type: ignore[misc]
@@ -130,7 +129,7 @@ def has_len_all_ranks(
     except (TypeError, NotImplementedError):
         has_len = False
 
-    # we are checking using lightning.lite, which doesn't know CombinedLoader
+    # we are checking using lightning.fabric, which doesn't know CombinedLoader
     if has_len and new_has_iterable_dataset(dataloader):  # type: ignore [arg-type]
         rank_zero_warn(
             "Your `IterableDataset` has `__len__` defined."
@@ -427,7 +426,7 @@ def _is_dataloader_shuffled(dataloader: object) -> bool:
 def has_iterable_dataset(*args: Any, **kwargs: Any) -> Any:
     rank_zero_deprecation(
         "`lightning.pytorch.utilities.data.has_iterable_dataset` has been deprecated in v1.8.0 and will be"
-        " removed in v1.10.0. Please use `lightning.lite.utilities.data.has_iterable_dataset` instead."
+        " removed in v2.0.0. Please use `lightning.fabric.utilities.data.has_iterable_dataset` instead."
     )
     return new_has_iterable_dataset(*args, **kwargs)
 
@@ -435,6 +434,6 @@ def has_iterable_dataset(*args: Any, **kwargs: Any) -> Any:
 def has_len(*args: Any, **kwargs: Any) -> Any:
     rank_zero_deprecation(
         "`lightning.pytorch.utilities.data.has_len` has been deprecated in v1.8.0 and will be"
-        " removed in v1.10.0. Please use `lightning.lite.utilities.data.has_len` instead."
+        " removed in v2.0.0. Please use `lightning.fabric.utilities.data.has_len` instead."
     )
     return new_has_len(*args, **kwargs)
