@@ -17,10 +17,10 @@ from typing import Any, Generator
 
 import torch
 
-from lightning.lite.utilities.seed import _collect_rng_states, _set_rng_states
-from lightning.lite.utilities.seed import pl_worker_init_function as new_pl_worker_init_function
-from lightning.lite.utilities.seed import reset_seed as new_reset_seed
-from lightning.lite.utilities.seed import seed_everything as new_seed_everything
+from lightning.fabric.utilities.seed import _collect_rng_states, _set_rng_states
+from lightning.fabric.utilities.seed import pl_worker_init_function as new_pl_worker_init_function
+from lightning.fabric.utilities.seed import reset_seed as new_reset_seed
+from lightning.fabric.utilities.seed import seed_everything as new_seed_everything
 from lightning.pytorch.utilities.rank_zero import rank_zero_deprecation
 
 
@@ -47,7 +47,7 @@ def isolate_rng() -> Generator[None, None, None]:
 def seed_everything(*args: Any, **kwargs: Any) -> Any:
     rank_zero_deprecation(
         "`lightning.pytorch.utilities.seed.seed_everything` has been deprecated in v1.8.0 and will be"
-        " removed in v1.10.0. Please use `lightning.lite.utilities.seed.seed_everything` instead."
+        " removed in v2.0.0. Please use `lightning.fabric.utilities.seed.seed_everything` instead."
     )
     return new_seed_everything(*args, **kwargs)
 
@@ -55,7 +55,7 @@ def seed_everything(*args: Any, **kwargs: Any) -> Any:
 def reset_seed() -> None:
     rank_zero_deprecation(
         "`lightning.pytorch.utilities.seed.reset_seed` has been deprecated in v1.8.0 and will be"
-        " removed in v1.10.0. Please use `lightning.lite.utilities.seed.reset_seed` instead."
+        " removed in v2.0.0. Please use `lightning.fabric.utilities.seed.reset_seed` instead."
     )
     return new_reset_seed()
 
@@ -63,6 +63,6 @@ def reset_seed() -> None:
 def pl_worker_init_function(*args: Any, **kwargs: Any) -> None:
     rank_zero_deprecation(
         "`lightning.pytorch.utilities.seed.pl_worker_init_function` has been deprecated in v1.8.0 and will be"
-        " removed in v1.10.0. Please use `lightning.lite.utilities.seed.pl_worker_init_function` instead."
+        " removed in v2.0.0. Please use `lightning.fabric.utilities.seed.pl_worker_init_function` instead."
     )
     return new_pl_worker_init_function(*args, **kwargs)
